#
# spec file for package python-pycares
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-pycares
Version:        4.5.0
Release:        1.1
Summary:        Python interface for c-ares
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/saghul/pycares
Source:         https://files.pythonhosted.org/packages/source/p/pycares/pycares-%{version}.tar.gz
# PATCH-FIX-UPSTREAM cleanup_tests.patch bsc#[0-9]+ mcepl@suse.com
# Make the test suite slightly more normal
Patch0:         cleanup_tests.patch
BuildRequires:  %{python_module cffi}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  c-ares-devel
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  python-rpm-macros
Requires:       python-cffi
Recommends:     python-idna
%python_subpackages

%description
pycares is a Python module which provides an interface to
c-ares. c-ares is a C library that performs DNS requests and name
resolutions asynchronously

%prep
%autosetup -p1 -n pycares-%{version}

rm -Rf

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# Test suite is broken anywhere else outside of the upstream CI,
# and upstream doesn't care.
# %%pyunittest_arch -v tests.tests

%files %{python_files}
%license LICENSE
%doc ChangeLog README.rst
%{python_sitearch}/*

%changelog
* Fri Jan 10 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 4.5.0
  * Test data updates to fix test failures
  * Update test_idna_encoding_query_a with
    new errno to align to new c-ares version
  * Do not define HAVE_GETSERVBYPORT_R for
    platforms Android, Cygwin, Darwin
  * Drop distutils
  * build(deps): bump actions/download-artifact
    from 3 to 4.1.7 in /.github/workflows
  * Add 3.13 support, remove 3.8
  * chore(ci): fix upload & add more platforms to cibuildwheel
  * Test building release wheels on PRs
  * Fix building sdist
  * Fixup CI
* Mon Dec 11 2023 Dirk Müller <dmueller@suse.com>
- update to 4.4.0:
  * Add support for 3.12, drop EOL 3.7
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 4.3.0
  * Bump cibuildwheel to build for Python 3.11 + CI total time speedups by @Jackenmen in #174
  Fix tests that depended on external sites by @Jackenmen in #180
  Complete the Python 3.11 support by @Jackenmen in #179
  Drop CPython 3.6 by @saghul in #181
  Improve test compatibility with pytest by @saghul in #182
  Update c-ares submodule to 1.18.1 by @saghul in #183
* Thu Dec  8 2022 Matej Cepl <mcepl@suse.com>
- Add cleanup_tests.patch to make the test suite slightly more sane.
- No, the test suite is just broken, and the upstream doesn't care.
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 4.2.2
  no changelog
* Mon Jul 11 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 4.2.1:
  * core: add flexible member to ares_addrinfo to fix c-ares 1.18
- changes from version 4.2.0:
  * tests: ignoring 2 tests due to dead servers
  * tests: updated google TXT records for an outdated test
  * deps: update bundled c-ares
- changes from version 4.1.2:
  * build: add PYPIREADME.rst to manifest
- changes from version 4.1.1:
  * misc: add PyPI README without images
  * misc: update c-ares URL
- changes from version 4.1.0:
  * ci: use stable 3.10, rather than dev
  * core: add support for Python 3.10
  * doc: fix typo in README
  * doc: updatee changelog
  * doc: uppdate README
  * core: add support for CAA queries
  * core: add support for getaddrinfo()
  * doc: update README
  * core: add ability to use the system installed c-ares
* Mon May 31 2021 Adrian Schröter <adrian@suse.de>
- update to 4.0.0
  * core: add support for CAA queries
  * core: add support for getaddrinfo()
  * core: add ability to use the system installed c-ares
  * test: remove TTL tests
  * core: update c-ares and use a submodule
  * core: drop bundled c-ares version
  * misc: drop tasks.py
* Thu Mar 19 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.1.1
  * misc: add Python 3.8 classifier
  * ci: run tests in Python 3.8 too
  * test: remove no longer valid test
  * test: remove empty test
  * errno: return str from errno.strerror
  * core: fix crash when processing .onion queries
  * core: fix support for ARES_OPT_LOOKUPS option
  * misc: simplify non-ascii txt test example
  * core: fix long TXT record with non-ascii bytes
* Thu Mar 21 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 3.0.0
  * first stable version in 3.0 series
* Fri Mar  1 2019 Ondřej Súkup <mimi.vx@gmail.com>
- initial commit
